QueryFailed

Struct QueryFailed 

pub struct QueryFailed {
    raw: String,
    code: String,
    line: usize,
    position: usize,
    message: String,
    file: String,
}
The error type for failed query execution.

Fields

raw: Stringcode: Stringline: usizeposition: usizemessage: Stringfile: String

Implementations

Source

impl QueryFailed

pub(crate) fn new(raw: String) -> Self

pub fn raw(&self) -> &str

The unparsed error string.

pub fn code(&self) -> &str

The XQuery error code.

pub fn line(&self) -> usize

The line in the file where the error occurred.

pub fn position(&self) -> usize

The character position in the line where the error occurred.

pub fn message(&self) -> &str

The error message.

pub fn file(&self) -> &str

The XQuery source file. Is presented as . (dot character) when not from file.